==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/da.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Tokener til anmodning om hentning mislykkedes. Verificér at dine app-nøgle og -hemmelighed er korrekte.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Tokener for adgang til hentning fejlede. Verificér at dine app-nøgle og -hemmelighed er korrekte.",
    "Please provide a valid app key and secret." : "Angiv venligst gyldig app-nøgle og -hemmelighed.",
    "Step 1 failed. Exception: %s" : "Trin 1 mislykkedes. Undtagelse: %s",
    "Step 2 failed. Exception: %s" : "Trin 2 mislykkedes. Undtagelse: %s",
    "External storage" : "Eksternt lager",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Godkend adgang",
    "Error configuring OAuth1" : "Fejl under konfiguration af OAuth1",
    "Error configuring OAuth2" : "Fejl under konfiguration af OAuth2",
    "Generate keys" : "Opret nøgler.",
    "Error generating key pair" : "Fejl under oprettelse af nøglepar",
    "All users. Type to select user or group." : "Alle brugere. Indtast for at vælge bruger eller gruppe.",
    "(group)" : "(gruppe)",
    "Admin defined" : "Bestemt af administrator",
    "Saved" : "Gemt",
    "Save" : "Gem",
    "Empty response from the server" : "Svar fra serveren uden data",
    "Username" : "Brugernavn",
    "Password" : "Kodeord",
    "Storage with id \"%i\" not found" : "Lager med ID'et \"%i% er ikke fundet",
    "Invalid backend or authentication mechanism class" : "Ugyldig backend eller klasse for godkendelsesmekanisme",
    "Invalid mount point" : "Fokert monteringspunkt",
    "Objectstore forbidden" : "Objectstore er forbudt",
    "Invalid storage backend \"%s\"" : "Forkert lager til backend \"%s\"en",
    "Not permitted to use backend \"%s\"" : "Ikke tilladt at bruge backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ikke tilladt at bruge autorisation mekanismen \"%s\"",
    "Unsatisfied backend parameters" : "Utilfredsstillede backend-parametre",
    "Unsatisfied authentication mechanism parameters" : "Utilfredsstillede parametre for godkendelsesmekanisme",
    "Insufficient data: %s" : "Utilstrækkelige data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lageret med id \"%i\" kan ikke redigeres af bruger",
    "Access key" : "Adgangsnøgle",
    "Secret key" : "Hemmelig nøgle",
    "Builtin" : "Indbygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nøgle",
    "App secret" : "App-hemmelighed",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klient hemmelighed",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Lejernavn",
    "Identity endpoint URL" : "Identificer afslutnings URL",
    "Rackspace" : "Hyldeplads",
    "API key" : "API nøgle",
    "Username and password" : "Brugernavn og kodeord",
    "RSA public key" : "RSA offentlig nøgle",
    "Public key" : "Offentlig nøgle",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Værtsnavn",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Aktivér SSL",
    "Enable Path Style" : "Aktivér stil for sti",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjernundermappe",
    "Secure https://" : "Sikker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Vært",
    "Secure ftps://" : "Sikker ftps://",
    "Google Drive" : "Google Drev",
    "Local" : "Lokal",
    "Location" : "Placering",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP med hemmelig nøglelogin",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Del",
    "Domain" : "Domæne",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-login",
    "Username as share" : "Brugernavn som deling",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Anmodning timeout (sekunder)",
    "No external storage configured" : "Der er ingen konfigurerede eksterne lagre",
    "You can add external storages in the personal settings" : "Du kan tilføje eksterne lagerenheder i de personlige indstillinger",
    "Name" : "Navn",
    "Storage type" : "Lagertype",
    "Scope" : "Anvendelsesområde",
    "Enable encryption" : "Slå kryptering til",
    "Enable previews" : "Slå forhåndsvisninger til",
    "Enable sharing" : "Slå deling til",
    "Check for changes" : "Tjek for ændringer",
    "Never" : "Aldrig",
    "Once every direct access" : "Kun ved hver direkte tilgang",
    "Folder name" : "Mappenavn",
    "Authentication" : "Godkendelse",
    "Configuration" : "Opsætning",
    "Available for" : "Tilgængelig for",
    "Add storage" : "Tilføj lager",
    "Advanced settings" : "Avancerede indstillinger",
    "Delete" : "Slet",
    "Allow users to mount the following external storage" : "Tillad brugere at montere følgende som eksternt lager"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/da.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Tokener til anmodning om hentning mislykkedes. Verificér at dine app-nøgle og -hemmelighed er korrekte.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Tokener for adgang til hentning fejlede. Verificér at dine app-nøgle og -hemmelighed er korrekte.",
    "Please provide a valid app key and secret." : "Angiv venligst gyldig app-nøgle og -hemmelighed.",
    "Step 1 failed. Exception: %s" : "Trin 1 mislykkedes. Undtagelse: %s",
    "Step 2 failed. Exception: %s" : "Trin 2 mislykkedes. Undtagelse: %s",
    "External storage" : "Eksternt lager",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Godkend adgang",
    "Error configuring OAuth1" : "Fejl under konfiguration af OAuth1",
    "Error configuring OAuth2" : "Fejl under konfiguration af OAuth2",
    "Generate keys" : "Opret nøgler.",
    "Error generating key pair" : "Fejl under oprettelse af nøglepar",
    "All users. Type to select user or group." : "Alle brugere. Indtast for at vælge bruger eller gruppe.",
    "(group)" : "(gruppe)",
    "Admin defined" : "Bestemt af administrator",
    "Saved" : "Gemt",
    "Saving..." : "Gemmer...",
    "Save" : "Gem",
    "Empty response from the server" : "Svar fra serveren uden data",
    "There was an error with message: " : "Der var et problem med beskeden:",
    "external-storage" : "Eksternt lager",
    "Username" : "Brugernavn",
    "Password" : "Kodeord",
    "Invalid backend or authentication mechanism class" : "Ugyldig backend eller klasse for godkendelsesmekanisme",
    "Invalid mount point" : "Fokert monteringspunkt",
    "Objectstore forbidden" : "Objectstore er forbudt",
    "Invalid storage backend \"%s\"" : "Forkert lager til backend \"%s\"en",
    "Not permitted to use backend \"%s\"" : "Ikke tilladt at bruge backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ikke tilladt at bruge autorisation mekanismen \"%s\"",
    "Unsatisfied backend parameters" : "Utilfredsstillede backend-parametre",
    "Unsatisfied authentication mechanism parameters" : "Utilfredsstillede parametre for godkendelsesmekanisme",
    "Insufficient data: %s" : "Utilstrækkelige data: %s",
    "%s" : "%s",
    "Access key" : "Adgangsnøgle",
    "Secret key" : "Hemmelig nøgle",
    "Builtin" : "Indbygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nøgle",
    "App secret" : "App-hemmelighed",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klient hemmelighed",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Lejernavn",
    "Identity endpoint URL" : "Identificer afslutnings URL",
    "Rackspace" : "Hyldeplads",
    "API key" : "API nøgle",
    "Username and password" : "Brugernavn og kodeord",
    "RSA public key" : "RSA offentlig nøgle",
    "Public key" : "Offentlig nøgle",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Værtsnavn",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Aktivér SSL",
    "Enable Path Style" : "Aktivér stil for sti",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjernundermappe",
    "Secure https://" : "Sikker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Vært",
    "Secure ftps://" : "Sikker ftps://",
    "Google Drive" : "Google Drev",
    "Local" : "Lokal",
    "Location" : "Placering",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP med hemmelig nøglelogin",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Del",
    "Domain" : "Domæne",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-login",
    "Username as share" : "Brugernavn som deling",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Anmodning timeout (sekunder)",
    "No external storage configured" : "Der er ingen konfigurerede eksterne lagre",
    "You can add external storages in the personal settings" : "Du kan tilføje eksterne lagerenheder i de personlige indstillinger",
    "Name" : "Navn",
    "Storage type" : "Lagertype",
    "Scope" : "Anvendelsesområde",
    "Enable encryption" : "Slå kryptering til",
    "Enable previews" : "Slå forhåndsvisninger til",
    "Enable sharing" : "Slå deling til",
    "Check for changes" : "Tjek for ændringer",
    "Never" : "Aldrig",
    "Once every direct access" : "Kun ved hver direkte tilgang",
    "Folder name" : "Mappenavn",
    "Authentication" : "Godkendelse",
    "Configuration" : "Opsætning",
    "Available for" : "Tilgængelig for",
    "Add storage" : "Tilføj lager",
    "Advanced settings" : "Avancerede indstillinger",
    "Delete" : "Slet",
    "Allow users to mount the following external storage" : "Tillad brugere at montere følgende som eksternt lager",
    "Storage with id \"%i\" not found" : "Lager med ID'et \"%i% er ikke fundet",
    "Storage with id \"%i\" is not user editable" : "Lageret med id \"%i\" kan ikke redigeres af bruger"
},
"nplurals=2; plural=(n != 1);");
